@@ -1,7 +1,7 @@
 from python_framework.api.src.annotation import EnumAnnotation
 
 from python_framework.api.src.util import FlaskUtil
-from python_framework.api.src.util import FlaskHelper
+from python_framework.api.src.util import Serializer
 
 from python_framework.api.src.service import ExceptionHandler
 from python_framework.api.src.service.ExceptionHandler import GlobalException
